@@ -1400,6 +1400,8 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
         scaleMode = pdfOptionsPage->scaleMode();
     }
 
+    const auto overprintPreviewEnabled = PDFSettings::overprintPreviewEnabled();
+
 #ifdef Q_OS_WIN
     // Windows can only print by rasterization, because that is
     // currently the only way Okular implements printing without using UNIX-specific
@@ -1409,6 +1411,7 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
 
     if (forceRasterize) {
         pdfdoc->setRenderHint(Poppler::Document::HideAnnotations, !printAnnots);
+        pdfdoc->setRenderHint(Poppler::Document::OverprintPreview, overprintPreviewEnabled);
 
         if (pdfOptionsPage) {
             // If requested, scale to full page instead of the printable area
@@ -1462,9 +1465,8 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
     // Get the real page size to pass to the ps generator
     QPrinter dummy(QPrinter::PrinterResolution);
     dummy.setFullPage(true);
-    dummy.setOrientation(printer.orientation());
-    dummy.setPageSize(printer.pageSize());
-    dummy.setPaperSize(printer.paperSize(QPrinter::Millimeter), QPrinter::Millimeter);
+    dummy.setPageOrientation(printer.pageLayout().orientation());
+    dummy.setPageSize(printer.pageLayout().pageSize());
     int width = dummy.width();
     int height = dummy.height();
 #else
@@ -1510,6 +1512,11 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
     psConverter->setForceRasterize(forceRasterize);
     psConverter->setTitle(pstitle);
 
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 9, 0)
+    const auto isPdfOutput = printer.outputFormat() == QPrinter::PdfFormat;
+    psConverter->setForceOverprintPreview(!isPdfOutput && overprintPreviewEnabled);
+#endif
+
     if (!printAnnots) {
         psConverter->setPSOptions(psConverter->psOptions() | Poppler::PSConverter::HideAnnotations);
     }
