@@ -17,7 +17,6 @@
 #include <QLoggingCategory>
 #include <QStack>
 #include <QVariant>
-#include <QXmlDefaultHandler>
 #include <QXmlStreamReader>
 
 #include <kzip.h>
@@ -43,7 +42,7 @@ class XpsRenderNode
 public:
     QString name;
     QVector<XpsRenderNode> children;
-    QXmlAttributes attributes;
+    QXmlStreamAttributes attributes;
     QVariant data;
 
     const XpsRenderNode *findChild(const QString &name) const;
@@ -79,6 +78,7 @@ struct XpsPathFigure {
     QPainterPath path;
     bool isFilled;
 };
+
 struct XpsPathGeometry {
     XpsPathGeometry()
         : fillRule(Qt::OddEvenFill)
@@ -100,41 +100,6 @@ struct XpsPathGeometry {
 class XpsPage;
 class XpsFile;
 
-class XpsHandler : public QXmlDefaultHandler
-{
-public:
-    explicit XpsHandler(XpsPage *page);
-    ~XpsHandler() override;
-
-    bool startElement(const QString &nameSpace, const QString &localName, const QString &qname, const QXmlAttributes &atts) override;
-    bool endElement(const QString &nameSpace, const QString &localName, const QString &qname) override;
-    bool startDocument() override;
-
-protected:
-    XpsPage *m_page;
-
-    void processStartElement(XpsRenderNode &node);
-    void processEndElement(XpsRenderNode &node);
-
-    // Methods for processing of different xml elements
-    void processGlyph(XpsRenderNode &node);
-    void processPath(XpsRenderNode &node);
-    void processPathData(XpsRenderNode &node);
-    void processFill(XpsRenderNode &node);
-    void processStroke(XpsRenderNode &node);
-    void processImageBrush(XpsRenderNode &node);
-    void processPathGeometry(XpsRenderNode &node);
-    void processPathFigure(XpsRenderNode &node);
-
-    QPainter *m_painter;
-
-    QImage m_image;
-
-    QStack<XpsRenderNode> m_nodes;
-
-    friend class XpsPage;
-};
-
 class XpsPage
 {
 public:
@@ -156,8 +121,21 @@ public:
     }
 
 private:
+    // Methods for processing of different xml elements
+    void processStartElement(QPainter *painter, XpsRenderNode &node);
+    void processEndElement(QPainter *painter, XpsRenderNode &node);
+    void processGlyph(QPainter *painter, XpsRenderNode &node);
+    void processPath(QPainter *painter, XpsRenderNode &node);
+    void processPathData(XpsRenderNode &node);
+    void processFill(XpsRenderNode &node);
+    void processStroke(XpsRenderNode &node);
+    void processImageBrush(XpsRenderNode &node);
+    void processPathGeometry(XpsRenderNode &node);
+    void processPathFigure(XpsRenderNode &node);
+
     XpsFile *m_file;
     const QString m_fileName;
+    QStack<XpsRenderNode> m_nodes;
 
     QSizeF m_pageSize;
 
@@ -312,7 +290,7 @@ public:
     Okular::ExportFormat::List exportFormats() const override;
     bool exportTo(const QString &fileName, const Okular::ExportFormat &format) override;
 
-    bool print(QPrinter &printer) override;
+    Okular::Document::PrintError print(QPrinter &printer) override;
 
 protected:
     bool doCloseDocument() override;
