@@ -15,12 +15,18 @@
 #ifndef _PART_H_
 #define _PART_H_
 
+#include <config-okular.h>
+
+#if HAVE_DBUS
+#include <QDBusAbstractAdaptor> // for Q_NOREPLY
+#else                           // HAVE_DBUS
+#define Q_NOREPLY
+#endif // HAVE_DBUS
 #include <QIcon>
 #include <QList>
 #include <QPointer>
 #include <QProcess>
 #include <QUrl>
-#include <QtDBus> // krazy:exclude=includes
 
 #include <KCompressionDevice>
 #include <KIO/Job>
@@ -35,8 +41,6 @@
 
 #include "okularpart_export.h"
 
-#include <config-okular.h>
-
 class QAction;
 class QWidget;
 class QPrinter;
@@ -74,7 +78,7 @@ class DrawingToolActions;
 class Layers;
 class SignaturePanel;
 
-#if PURPOSE_FOUND
+#if HAVE_PURPOSE
 namespace Purpose
 {
 class Menu;
@@ -309,7 +313,7 @@ private:
     void setFileToWatch(const QString &filePath);
     void unsetFileToWatch();
 
-#if PURPOSE_FOUND
+#if HAVE_PURPOSE
     void slotShareActionFinished(const QJsonObject &output, int error, const QString &message);
 #endif
 
@@ -405,7 +409,7 @@ private:
     QAction *m_exportAs;
     QAction *m_exportAsText;
     QAction *m_exportAsDocArchive;
-#if PURPOSE_FOUND
+#if HAVE_PURPOSE
     QAction *m_share;
 #endif
     QAction *m_showPresentation;
@@ -419,7 +423,7 @@ private:
     QAction *m_aboutBackend;
     QAction *m_reload;
     QMenu *m_exportAsMenu;
-#if PURPOSE_FOUND
+#if HAVE_PURPOSE
     Purpose::Menu *m_shareMenu;
 #endif
     QAction *m_closeFindBar;
