@@ -5,11 +5,14 @@
 */
 
 #include "presentationwidget.h"
+#include "config-okular.h"
 
 // qt/kde includes
+#if HAVE_DBUS
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusReply>
+#endif
 #include <QLoggingCategory>
 
 #include <KActionCollection>
@@ -19,6 +22,7 @@
 #include <KMessageBox>
 #include <KSelectAction>
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
 #include <QDialog>
 #include <QEvent>
@@ -39,7 +43,9 @@
 #include <QValidator>
 
 #ifdef Q_OS_LINUX
+#if HAVE_DBUS
 #include <QDBusUnixFileDescriptor>
+#endif
 #include <unistd.h> // For ::close() for sleep inhibition
 #endif
 
@@ -824,8 +830,8 @@ void PresentationWidget::paintEvent(QPaintEvent *pe)
     }
 
     // check painting rect consistency
-    QRect r = pe->rect().intersected(QRect(QPoint(0, 0), geometry().size()));
-    if (r.isNull()) {
+    QRect paintRect = pe->rect().intersected(QRect(QPoint(0, 0), geometry().size()));
+    if (paintRect.isNull()) {
         return;
     }
 
@@ -1697,6 +1703,7 @@ void PresentationWidget::setScreen(const QScreen *newScreen)
 
 void PresentationWidget::inhibitPowerManagement()
 {
+#if HAVE_DBUS
 #ifdef Q_OS_LINUX
     QString reason = i18nc("Reason for inhibiting the screensaver activation, when the presentation mode is active", "Giving a presentation");
 
@@ -1730,11 +1737,13 @@ void PresentationWidget::inhibitPowerManagement()
             qCWarning(OkularUiDebug) << "Unable to inhibit sleep" << reply.error();
         }
     }
-#endif
+#endif // Q_OS_LINUX
+#endif // HAVE_DBUS
 }
 
 void PresentationWidget::allowPowerManagement()
 {
+#if HAVE_DBUS
 #ifdef Q_OS_LINUX
     if (m_sleepInhibitFd != -1) {
         ::close(m_sleepInhibitFd);
@@ -1750,7 +1759,8 @@ void PresentationWidget::allowPowerManagement()
 
         m_screenInhibitCookie = 0;
     }
-#endif
+#endif // Q_OS_LINUX
+#endif // HAVE_DBUS
 }
 
 void PresentationWidget::showTopBar(bool show)
@@ -1810,113 +1820,94 @@ const Okular::PageTransition PresentationWidget::defaultTransition(int type) con
         Okular::PageTransition transition(Okular::PageTransition::Blinds);
         transition.setAlignment(Okular::PageTransition::Horizontal);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::BlindsVertical: {
         Okular::PageTransition transition(Okular::PageTransition::Blinds);
         transition.setAlignment(Okular::PageTransition::Vertical);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::BoxIn: {
         Okular::PageTransition transition(Okular::PageTransition::Box);
         transition.setDirection(Okular::PageTransition::Inward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::BoxOut: {
         Okular::PageTransition transition(Okular::PageTransition::Box);
         transition.setDirection(Okular::PageTransition::Outward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::Dissolve: {
         return Okular::PageTransition(Okular::PageTransition::Dissolve);
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::GlitterDown: {
         Okular::PageTransition transition(Okular::PageTransition::Glitter);
         transition.setAngle(270);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::GlitterRight: {
         Okular::PageTransition transition(Okular::PageTransition::Glitter);
         transition.setAngle(0);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::GlitterRightDown: {
         Okular::PageTransition transition(Okular::PageTransition::Glitter);
         transition.setAngle(315);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::Random: {
         return defaultTransition(QRandomGenerator::global()->bounded(18));
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::SplitHorizontalIn: {
         Okular::PageTransition transition(Okular::PageTransition::Split);
         transition.setAlignment(Okular::PageTransition::Horizontal);
         transition.setDirection(Okular::PageTransition::Inward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::SplitHorizontalOut: {
         Okular::PageTransition transition(Okular::PageTransition::Split);
         transition.setAlignment(Okular::PageTransition::Horizontal);
         transition.setDirection(Okular::PageTransition::Outward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::SplitVerticalIn: {
         Okular::PageTransition transition(Okular::PageTransition::Split);
         transition.setAlignment(Okular::PageTransition::Vertical);
         transition.setDirection(Okular::PageTransition::Inward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::SplitVerticalOut: {
         Okular::PageTransition transition(Okular::PageTransition::Split);
         transition.setAlignment(Okular::PageTransition::Vertical);
         transition.setDirection(Okular::PageTransition::Outward);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::WipeDown: {
         Okular::PageTransition transition(Okular::PageTransition::Wipe);
         transition.setAngle(270);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::WipeRight: {
         Okular::PageTransition transition(Okular::PageTransition::Wipe);
         transition.setAngle(0);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::WipeLeft: {
         Okular::PageTransition transition(Okular::PageTransition::Wipe);
         transition.setAngle(180);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::WipeUp: {
         Okular::PageTransition transition(Okular::PageTransition::Wipe);
         transition.setAngle(90);
         return transition;
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::Fade: {
         return Okular::PageTransition(Okular::PageTransition::Fade);
-        break;
     }
     case Okular::Settings::EnumSlidesTransition::NoTransitions:
     case Okular::Settings::EnumSlidesTransition::Replace:
     default:
         return Okular::PageTransition(Okular::PageTransition::Replace);
-        break;
     }
     // should not happen, just make gcc happy
     return Okular::PageTransition();
