@@ -95,7 +95,8 @@ public:
     static constexpr char ConfigKey[] = "RecentBackgrounds";
     RecentImagesModel()
     {
-        for (auto &element : KSharedConfig::openConfig()->group(QLatin1String(ConfigGroup)).readEntry<QStringList>(QLatin1String(ConfigKey), QStringList())) {
+        const auto recentList = KSharedConfig::openConfig()->group(QLatin1String(ConfigGroup)).readEntry<QStringList>(QLatin1String(ConfigKey), QStringList());
+        for (const auto &element : recentList) {
             if (QFile::exists(element)) { // maybe the image has been removed from disk since last invocation
                 m_storedElements.push_back(element);
             }
@@ -314,7 +315,7 @@ std::optional<SigningInformation> getCertificateAndPasswordForSigning(PageView *
             if (recentModel->rowCount() > 1 || actions.empty()) {
                 actions.append(&allImages);
             }
-            QAction *selected = QMenu::exec(actions, view->viewport()->mapToGlobal(pos), nullptr, view);
+            const QAction *selected = QMenu::exec(actions, view->viewport()->mapToGlobal(pos), nullptr, view);
             if (selected == &currentImage) {
                 recentModel->removeItem(current.data(Qt::DisplayRole).toString());
                 recentModel->saveBack();
