@@ -21,7 +21,7 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
-#include <QDBusInterface>
+#include <QStringList>
 #include <QTextStream>
 #include <QtGlobal>
 
