@@ -25,7 +25,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <KRecentFilesAction>
 #include <KSharedConfig>
 #include <KStandardAction>
@@ -36,11 +35,15 @@
 #include <KWindowSystem>
 #include <KXMLGUIFactory>
 #include <QApplication>
+#if HAVE_DBUS
 #include <QDBusConnection>
+#endif // HAVE_DBUS
 #include <QDockWidget>
 #include <QDragMoveEvent>
 #include <QFileDialog>
+#include <QJsonArray>
 #include <QMenuBar>
+#include <QMimeData>
 #include <QObject>
 #include <QScreen>
 #include <QTabBar>
@@ -164,14 +167,17 @@ Shell::Shell(const QString &serializedOptions)
     // this routine will find and load our Part.  it finds the Part by
     // name which is a bad idea usually.. but it's alright in this
     // case since our Part is made for this Shell
-    KPluginLoader loader(QStringLiteral("okularpart"));
-    m_partFactory = loader.factory();
-    if (!m_partFactory) {
+
+    const auto result = KPluginFactory::loadFactory(KPluginMetaData(QStringLiteral("okularpart")));
+
+    if (!result) {
         // if we couldn't find our Part, we exit since the Shell by
         // itself can't do anything useful
         m_isValid = false;
-        KMessageBox::error(this, i18n("Unable to find the Okular component: %1", loader.errorString()));
+        KMessageBox::error(this, i18n("Unable to find the Okular component: %1", result.errorString));
         return;
+    } else {
+        m_partFactory = result.plugin;
     }
 
     // now that the Part plugin is loaded, create the part
@@ -237,6 +243,7 @@ Shell::Shell(const QString &serializedOptions)
         readSettings();
 
         m_unique = ShellUtils::unique(serializedOptions);
+#if HAVE_DBUS
         if (m_unique) {
             m_unique = QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.okular"));
             if (!m_unique) {
@@ -258,6 +265,7 @@ Shell::Shell(const QString &serializedOptions)
         }
 
         QDBusConnection::sessionBus().registerObject(QStringLiteral("/okularshell"), this, QDBusConnection::ExportScriptableSlots);
+#endif // HAVE_DBUS
 
         // Make sure that the welcome scren is visible on startup.
         showWelcomeScreen();
@@ -333,9 +341,11 @@ Shell::~Shell()
         }
         m_tabs.clear();
     }
+#if HAVE_DBUS
     if (m_unique) {
         QDBusConnection::sessionBus().unregisterService(QStringLiteral("org.kde.okular"));
     }
+#endif // HAVE_DBUS
 
     delete m_tabWidget;
 }
